# coding: utf-8

"""
    Hatchet API

    The Hatchet API

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set, Union

from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    StrictFloat,
    StrictInt,
    StrictStr,
    field_validator,
)
from typing_extensions import Self


class TenantBillingStateGet200ResponseCouponsInner(BaseModel):
    """
    TenantBillingStateGet200ResponseCouponsInner
    """  # noqa: E501

    name: StrictStr = Field(description="The name of the coupon.")
    amount_cents: Optional[StrictInt] = Field(
        default=None, description="The amount off of the coupon."
    )
    amount_cents_remaining: Optional[StrictInt] = Field(
        default=None, description="The amount remaining on the coupon."
    )
    amount_currency: Optional[StrictStr] = Field(
        default=None, description="The currency of the coupon."
    )
    frequency: StrictStr = Field(description="The frequency of the coupon.")
    frequency_duration: Optional[StrictInt] = Field(
        default=None, description="The frequency duration of the coupon."
    )
    frequency_duration_remaining: Optional[StrictInt] = Field(
        default=None, description="The frequency duration remaining of the coupon."
    )
    percent: Optional[Union[StrictFloat, StrictInt]] = Field(
        default=None, description="The percentage off of the coupon."
    )
    __properties: ClassVar[List[str]] = [
        "name",
        "amount_cents",
        "amount_cents_remaining",
        "amount_currency",
        "frequency",
        "frequency_duration",
        "frequency_duration_remaining",
        "percent",
    ]

    @field_validator("frequency")
    def frequency_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(["once", "recurring"]):
            raise ValueError("must be one of enum values ('once', 'recurring')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TenantBillingStateGet200ResponseCouponsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TenantBillingStateGet200ResponseCouponsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "name": obj.get("name"),
                "amount_cents": obj.get("amount_cents"),
                "amount_cents_remaining": obj.get("amount_cents_remaining"),
                "amount_currency": obj.get("amount_currency"),
                "frequency": obj.get("frequency"),
                "frequency_duration": obj.get("frequency_duration"),
                "frequency_duration_remaining": obj.get("frequency_duration_remaining"),
                "percent": obj.get("percent"),
            }
        )
        return _obj
